import logging
import os
from importlib.metadata import version

import click

from .util import random_list, save_all_lists, save_specific_list

logger = logging.getLogger(__name__)
env = os.environ.get("DEPLOYMENT_ENV", "prod")
log_level = logging.INFO
if env != "prod":
    log_level = logging.DEBUG
logging.basicConfig(level=log_level)


def print_version(ctx, param, value):
    # print(ctx.__dict__)
    # print(param.__dict__)
    # print(value)
    if not value or ctx.resilient_parsing:
        return
    click.echo(f'Version: {version("spotify-playlist")}')
    ctx.exit()


@click.group()
@click.option(
    '--version',
    is_flag=True,
    callback=print_version,
    expose_value=False,
    is_eager=True,
    help="Package version.",
)
def cli():
    pass


@cli.command()
@click.option(
    "--client-id", "-i",
    default="890f2ab03b8e4a94a33f66c9e83272ae",
    show_default=True,
    type=str,
    required=False,
    help="client id",
)
@click.option(
    "--client-secret", "-s",
    default="939cdd453c59404eacd2ff9682820920",
    show_default=True,
    type=str,
    required=False,
    help="client secret",
)
@click.option(
    "--redirect", "-r",
    default="https://localhost:8080/callback",
    show_default=True,
    type=str,
    required=False,
    help="redirect url",
)
@click.option(
    "--output-folder", "-o",
    default=os.getcwd(),
    show_default=True,
    type=click.Path(exists=True),
    required=False,
    help="output path.",
)
def all(**kwargs):
    env = {
        "SPOTIPY_CLIENT_ID": kwargs.get("client_id"),
        "SPOTIPY_CLIENT_SECRET": kwargs.get("client_secret"),
        "SPOTIPY_REDIRECT_URI": kwargs.get("redirect")
    }
    os.chdir(kwargs.get("output_folder"))
    save_all_lists(env)


@cli.command()
@click.option(
    "--client-id", "-i",
    default="890f2ab03b8e4a94a33f66c9e83272ae",
    show_default=True,
    type=str,
    required=False,
    help="client id",
)
@click.option(
    "--client-secret", "-s",
    default="939cdd453c59404eacd2ff9682820920",
    show_default=True,
    type=str,
    required=False,
    help="client secret",
)
@click.option(
    "--redirect", "-r",
    default="https://localhost:8080/callback",
    show_default=True,
    type=str,
    required=False,
    help="redirect url",
)
@click.option(
    "--output-folder", "-o",
    default=os.getcwd(),
    show_default=True,
    type=click.Path(exists=True),
    required=False,
    help="output path.",
)
@click.argument('playlist', nargs=-1)
def name(**kwargs):
    env = {
        "SPOTIPY_CLIENT_ID": kwargs.get("client_id"),
        "SPOTIPY_CLIENT_SECRET": kwargs.get("client_secret"),
        "SPOTIPY_REDIRECT_URI": kwargs.get("redirect")
    }
    os.chdir(kwargs.get("output_folder"))
    save_specific_list(env, kwargs.get("playlist"))


@cli.command()
@click.option(
    "--client-id", "-i",
    default="890f2ab03b8e4a94a33f66c9e83272ae",
    show_default=True,
    type=str,
    required=False,
    help="client id",
)
@click.option(
    "--client-secret", "-s",
    default="939cdd453c59404eacd2ff9682820920",
    show_default=True,
    type=str,
    required=False,
    help="client secret",
)
@click.option(
    "--redirect", "-r",
    default="https://localhost:8080/callback",
    show_default=True,
    type=str,
    required=False,
    help="redirect url",
)
def rand(**kwargs):
    env = {
        "SPOTIPY_CLIENT_ID": kwargs.get("client_id"),
        "SPOTIPY_CLIENT_SECRET": kwargs.get("client_secret"),
        "SPOTIPY_REDIRECT_URI": kwargs.get("redirect")
    }
    random_list(env)


if __name__ == "__main__":
    cli()



import logging
import os
import random

import spotipy
import unidecode
from spotipy.oauth2 import SpotifyOAuth

logger = logging.getLogger(__name__)


def save_all_lists(env):
    os.environ.update(env)
    scope = "user-library-modify,playlist-read-private,playlist-modify-private"
    spotify = spotipy.Spotify(auth_manager=SpotifyOAuth(scope=scope))
    os.makedirs("playlist", exist_ok=True)
    offset = 0
    count = 0
    while True:
        t = spotify.current_user_playlists(limit=50,offset=offset)["items"]
        for item in t:
            count += 1
            # spotify.playlist_change_details(item['id'], public=False)
            offset_song = 0
            with open(os.path.join("playlist", f"{item['name']}.csv"), 'w', encoding="utf-8") as file:
                while True:
                    tt = spotify.playlist_items(item['id'], offset=offset_song)
                    # print(item, len(tt["items"]))
                    for itemt in tt["items"]:
                        # logger.info(itemt['track']['name'] + " -- " + itemt['track']['album']['name'])
                        file.write('"{}","{}" \n'.format(itemt['track']['album']['name'], itemt['track']['name']))
                    if len(tt["items"]) < 100:
                        break
                    offset_song = offset_song + 100
            logger.info(f"{item['name']} updated")
        if len(t) < 50:
            break
        offset = offset + 50
    logger.info(f"{count} playlists updated")


def save_specific_list(env, names):
    os.environ.update(env)
    scope = "user-library-modify,playlist-read-private,playlist-modify-private"
    spotify = spotipy.Spotify(auth_manager=SpotifyOAuth(scope=scope))
    os.makedirs("playlist", exist_ok=True)
    offset = 0
    lower_names = [unidecode.unidecode(name).lower() for name in names]
    while True:
        t = spotify.current_user_playlists(limit=50,offset=offset)["items"]
        for item in t:
            uniname = unidecode.unidecode(item['name']).lower()
            update = False
            for n in lower_names:
                if uniname.startswith(n):
                    update = True
            if update:
                offset_song = 0
                with open(os.path.join("playlist", f"{item['name']}.csv"), 'w', encoding="utf-8") as file:
                    while True:
                        tt = spotify.playlist_items(item['id'], offset=offset_song)
                        # print(item, len(tt["items"]))
                        for itemt in tt["items"]:
                            # logger.info(itemt['track']['name'] + " -- " + itemt['track']['album']['name'])
                            file.write('"{}","{}" \n'.format(itemt['track']['album']['name'], itemt['track']['name']))
                        if len(tt["items"]) < 100:
                            break
                        offset_song = offset_song + 100
                logger.info(f"{item['name']} updated")
        if len(t) < 50:
            break
        offset = offset + 50


def random_list(env):
    os.environ.update(env)
    scope = "user-library-modify,playlist-read-private,playlist-modify-private"
    spotify = spotipy.Spotify(auth_manager=SpotifyOAuth(scope=scope))
    playlist = []
    offset = 0
    while True:
        t = spotify.current_user_playlists(limit=50,offset=offset)["items"]
        for item in t:
            playlist.append(item['name'])
        if len(t) < 50:
            break
        offset = offset + 50
    # print(playlist)
    os.system('cls')
    print('\n', random.choice(playlist), '\n')
    while True:
        input("")
        os.system('cls')
        print('\n', random.choice(playlist), '\n')
